import React, { useState } from 'react'
import { useDrop } from 'react-dnd'
import { is, fromJS } from 'immutable'
import update from 'immutability-helper'
import { Tabs } from 'antd'
import Card from './card'
import './index.scss'

const { TabPane } = Tabs

const Container = ({activeKey, list, expand, handleList, handleMenu, deleteMenu, changetabview }) => {
  const [cards, setCards] = useState(list)
  const moveCard = (id, atIndex) => {
    const { card, index } = findCard(id)
    const _cards = update(cards, { $splice: [[index, 1], [atIndex, 0, card]] })

    handleList(_cards)
  }

  if (!is(fromJS(cards), fromJS(list))) {
    setCards(list)
  }
  
  const findCard = id => {
    const card = cards.filter(c => `${c.uuid}` === id)[0]
    return {
      card,
      index: cards.indexOf(card),
    }
  }

  const editCard = id => {
    const { card } = findCard(id)
    handleMenu(card)
  }

  const delCard = id => {
    const { card } = findCard(id)
    deleteMenu(card)
  }

  const changetab = id => {
    if (activeKey === 'all') return
    
    changetabview(id)
  }

  const [, drop] = useDrop({
    accept: 'chart'
  })

  return (
    <div ref={drop} className="ant-row chart-edit-tab-box">
      <Tabs activeKey={!expand ? activeKey : ''} onChange={changetab}>
        {cards.map(card => (
          <TabPane tab={
            <div key={card.uuid}>
              <Card
                key={card.uuid}
                id={card.uuid}
                card={card}
                moveCard={moveCard}
                editCard={editCard}
                delCard={delCard}
                findCard={findCard}
              />
            </div>
          } key={card.uuid}></TabPane>
        ))}
      </Tabs>
    </div>
  )
}
export default Container
